import logging

from django.conf import settings
from django.contrib.auth.decorators import login_required
from django.http import HttpResponseBadRequest
from django.http import JsonResponse
from django.shortcuts import render
from reportserver.lib.export.types.esfexport import create_esfexport_for
from reportserver.lib.export.types.raw_data_export import get_metadata
from reportserver.lib.io.requests import get_selected_options_from
from reportserver.lib.report import reportservice
from reportserver.lib.general_export import get_datepicker_context

logger = logging.getLogger(__name__)


@login_required
def overview(request):
    """
    View for the esfreport
    :param request:
    :return: the rendered template
    """
    context = get_datepicker_context()
    return render(request, "esfreport.html", context=context)


@login_required
def report(request):
    """
    Endpoint for the report generation
    :param request:
    :return: a report in JSON format
    """
    try:
        filters = get_selected_options_from(request)
    except:
        return HttpResponseBadRequest()
    else:
        report = reportservice.create_report_for(settings.PROGRAM, filters)
        logger.info("'%s' requested a esfreport.", request.user.username)
        return JsonResponse(report.to_dict())


@login_required
def export_report(request):
    """
    Endpoint for export report as Excel
    :param request:
    :return:
    """
    try:
        filters = get_selected_options_from(request)
        metadata = get_metadata(request, "")
    except:
        return HttpResponseBadRequest()
    else:
        return create_esfexport_for(settings.PROGRAM, filters, metadata)
